@@ -12,8 +12,8 @@ import pandas as pd
 import copy
 from easyterm import *
 
-__all__=['extend_orfs','mod_genome_bounds', '_outside_bounds_j',
-         'mod_get_sequence','find_upstream_patterns','find_downstream_patterns'
+__all__=['general_extend_orfs','mod_genome_bounds', '_outside_bounds_j',
+         'mod_get_sequence','find_upstream_patterns','find_downstream_patterns',
          'filler','mod_extend','_extend_grp_j','mod_to_gff3'] ################################################################################################################### WORKING HERE
 
 def_opt={'p':'',
@@ -48,7 +48,7 @@ opt=command_line_options(def_opt, help_msg)
 
 # Definitions
 ################################################################################################################################################################ INPUT IS REGULAR DATAFRAME NOW
-def extend_orfs(p, fasta_path, cds_id = None, starts = ['ATG'], 
+def general_extend_orfs(p, fasta_path, cds_id = None, starts = ['ATG'], 
                 stops = ['TAG', 'TGA', 'TAA'], default_full = False, 
                 direction = ['up', 'down'], chunk_size = 900, o = None): 
 
